==> tine20-inventory_2019.12.5.tar.bz2: Inventory/js/Inventory-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pt_BR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Inventory item, Inventory items"
: [
  "Item de inventário"
 ,"itens de inventário"

]
, "Inventory item list, Inventory item lists"
: [
  "Listas de itens de inventário"
 ,"Listas de itens de inventário"

]
, "Name"
: "Nome"

, "Status"
: "Situação"

, "Inventory ID"
: "ID do Inventário"

, "Description"
: "Descrição"

, "Location"
: "Posição"

, "Invoice date"
: "Data da fatura"

, "Invoice"
: "Fatura"

, "Price"
: "Preço"

, "Cost Center"
: "Centro de Custo"

, "Warranty"
: "Garantia"

, "Item added"
: "Item adicionado"

, "Item removed"
: "Item removido"

, "Deprecate"
: "Depreciar"

, "The active number must be less than or equal total number."
: "O número ativo deve ser menor ou igual ao número total"

, "General"
: "Geral"

, "ID"
: "ID"

, "Enter description"
: "Informe a descrição"

, "Added"
: "Adicionado"

, "Removed"
: "Removido"

, "Total number"
: "Número total"

, "Available number"
: "Número disponível"

, "Accounting"
: "Contabilidade"

, "Cost center"
: ""

, "Depreciate"
: "Depreciar"

, "Default Inventory Item Container"
: "Repositório Padrão de Item de Inventário"

, "The default container for new items"
: "O repositório padrão para novos ítens"

, "Inventory Status Available"
: "Situação do Inventário Disponível"

, "Possible status."
: "Situação possível."

, "ordered"
: "ordenado"

, "available"
: "disponível"

, "defect"
: "defeito"

, "missing"
: "faltando"

, "removed"
: "removido"

, "unknown"
: "desconhecido"

, "Inventory CSV import"
: "Importar arquivo CVS de Inventário"

, "Import list (###CURRENTDATE###)"
: "Lista de Importação (###CURRENTDATE###)"

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Ítens importados  em ###CURRENTDATE### às ###CURRENTTIME### por ###USERFULLNAME###"

, "All Inventory Items"
: "Todos os ítens do inventário"

, "All existing Inventory Items"
: "Todos os ítens de inventário existentes"

, "Inventory"
: "Inventário"

, "Inventory item"
: "Item de inventário"

, "Inventory item list"
: "Listas de itens de inventário"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-inventory_2020.08.8.tar.bz2: Inventory/js/Inventory-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Inventory Item Container"
: "Repositório Padrão de Item de Inventário"

, "The default container for new items"
: "O repositório padrão para novos ítens"

, "The active number must be less than or equal total number."
: "O número ativo deve ser menor ou igual ao número total"

, "General"
: "Geral"

, "ID"
: "ID"

, "Name"
: "Nome"

, "Description"
: "Descrição"

, "Enter description"
: "Informe a descrição"

, "Location"
: "Posição"

, "Added"
: "Adicionado"

, "Warranty"
: "Garantia"

, "Removed"
: "Removido"

, "Total number"
: "Número total"

, "Available number"
: "Número disponível"

, "Status"
: "Situação"

, "Accounting"
: "Contabilidade"

, "Price"
: "Preço"

, "Cost center"
: ""

, "Invoice"
: "Fatura"

, "Invoice date"
: "Data da fatura"

, "Depreciate"
: "Depreciar"

, "All Inventory Items"
: "Todos os ítens do inventário"

, "All existing Inventory Items"
: "Todos os ítens de inventário existentes"

, "Inventory"
: "Inventário"

, "Inventory Status Available"
: "Situação do Inventário Disponível"

, "Possible status."
: "Situação possível."

, "ordered"
: "ordenado"

, "available"
: "disponível"

, "defect"
: "defeito"

, "missing"
: "faltando"

, "removed"
: "removido"

, "unknown"
: "desconhecido"

, "Inventory item, Inventory items"
: [
  "Item de inventário"
 ,"itens de inventário"

]
, "Inventory item list, Inventory item lists"
: [
  "Listas de itens de inventário"
 ,"Listas de itens de inventário"

]
, "Inventory ID"
: "ID do Inventário"

, "Cost Center"
: "Centro de Custo"

, "Item added"
: "Item adicionado"

, "Item removed"
: "Item removido"

, "Inventory CSV import"
: "Importar arquivo CVS de Inventário"

, "Import list (###CURRENTDATE###)"
: "Lista de Importação (###CURRENTDATE###)"

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Ítens importados  em ###CURRENTDATE### às ###CURRENTTIME### por ###USERFULLNAME###"


, "Inventory item"
: "Item de inventário"

, "Inventory item list"
: "Listas de itens de inventário"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
